// *************************************************************************************************
//
// Horde3D
//   Next-Generation Graphics Engine
//
// Sample chicagoGLWidget
// --------------------------------------
// Copyright (C) 2006-2008 Nicolas Schulz
//
//
// This sample source file is not covered by the LGPL as the rest of the SDK
// and may be used without any restrictions
//
// *************************************************************************************************

#ifndef CHICGLWIDGET_H
#define CHICGLWIDGET_H

#include <QGLWidget>
#include <QKeyEvent>
#include <sstream>

#include "crowd.h"

using namespace std;

class chicagoGLWidget : public QGLWidget
{
    Q_OBJECT

    public:

        chicagoGLWidget();
        ~chicagoGLWidget();

        void initializeGL();
        void paintGL();
        void resizeGL(int width, int height);
        void keyPressEvent(QKeyEvent *event);
        void keyStateChange(int key, bool state);
        void mouseMoveEvent(QMouseEvent *event);
        void mousePressEvent(QMouseEvent *event);

        QSize sizeHint() const;
        QSize minimumSizeHint() const;

    public slots:
        void animate();

    signals:
        void animated();

    private:

        QPoint          lastPos;

        bool			_keys[320];
        float			_x, _y, _z, _rx, _ry;	// Viewer position and orientation
        float			_velocity;				// Velocity for movement
        float			_curFPS, _timer;
        stringstream	_fpsText;

        bool			_freeze, _showFPS, _debugViewMode, _wireframeMode;

        CrowdSim		*_crowdSim;

        // Engine objects
        ResHandle		_fontMatRes, _logoMatRes, _forwardPipeRes, _deferredPipeRes;
        NodeHandle		_cam;
};

#endif // CHICGLWIDGET_H

